ChildrenX class

Constructors

ChildrenX({required List<AutoCalculate> autoCalculate, required String databaseParam, required String dependant, required String dependentOperator, required String dependentResult, required ElementData elementData, required int elementId, required ElementLabel elementLabel, required int elementSize, required ElementTooltip elementTooltip, required String elementType, required String inputType, required bool isDependent, required String isDisable, required String isEditable, required String isRequired, required String isSelection, required String operation, required String operator, required String operatorResult, required int parameter, required List<Validation> validation, required Map<String, String> elementOptionDependent, Style? style, String? elementValue, String? expression, String? isVisible, double? maxVal, double? minVal, AutofillItem? isAutofill})
const

Properties

autoCalculate List<AutoCalculate>
final
databaseParam String
final
dependant String
final
dependentOperator String
final
dependentResult String
final
elementData ElementData
final
elementId int
final
elementLabel ElementLabel
final
elementOptionDependent Map<String, String>
final
elementSize int
final
elementTooltip ElementTooltip
final
elementType String
final
elementValue String?
final
expression String?
final
hashCode int
The hash code for this object.
no setterinherited
inputType String
final
isAutofill AutofillItem?
final
isDependent bool
final
isDisable String
final
isEditable String
final
isRequired String
final
isSelection String
final
isVisible String?
final
maxVal double?
final
minVal double?
final
operation String
final
operator String
final
operatorResult String
final
parameter int
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
style Style?
final
validation List<Validation>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited