FormLogicBundle class
Constructors
-
FormLogicBundle({required Map<
int, ChildrenX> parameterMap, required Map<int, bool> visibilityMap, required Map<int, InputWrapper> valueMap, required Map<int, DependentValueCustomText> dependentValueMap, required Map<List< dependentOperatorMap, required Map<int> , List<int> >List< operatorMap, required Map<int> , List<int> >int, DependentValueCustomText> operatorValueMap, required Map<int, FocusNode> focusNodeMap}) -
const
Properties
-
dependentOperatorMap
→ Map<
List< int> , List<int> > -
final
-
dependentValueMap
→ Map<
int, DependentValueCustomText> -
final
-
focusNodeMap
→ Map<
int, FocusNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operatorMap
→ Map<
List< int> , List<int> > -
final
-
operatorValueMap
→ Map<
int, DependentValueCustomText> -
final
-
parameterMap
→ Map<
int, ChildrenX> -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setter -
valueMap
→ Map<
int, InputWrapper> -
final
-
visibilityMap
→ Map<
int, bool> -
final
Methods
-
copyWith(
{Map< int, ChildrenX> ? parameterMap, Map<int, bool> ? visibilityMap, Map<int, InputWrapper> ? valueMap, Map<int, DependentValueCustomText> ? dependentValueMap, Map<List< ? dependentOperatorMap, Map<int> , List<int> >List< ? operatorMap, Map<int> , List<int> >int, DependentValueCustomText> ? operatorValueMap, Map<int, FocusNode> ? focusNodeMap}) → FormLogicBundle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited