ElementLabel class
Constructors
Properties
- as → String?
-
final
- bn → String?
-
final
- en → String?
-
final
- gu → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hi → String?
-
final
- kn → String?
-
final
- mr → String?
-
final
- or → String?
-
final
- pa → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - ta → String?
-
final
- te → String?
-
final
- ur → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited